/*
*  Copyright (c) 2005-2010, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
*
*  WSO2 Inc. licenses this file to you under the Apache License,
*  Version 2.0 (the "License"); you may not use this file except
*  in compliance with the License.
*  You may obtain a copy of the License at
*
*    http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing,
* software distributed under the License is distributed on an
* "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
* KIND, either express or implied.  See the License for the
* specific language governing permissions and limitations
* under the License.
*/
package org.wso2.carbon.mediation.initializer.persistence;

import org.apache.axiom.om.OMElement;
import org.apache.synapse.config.SynapseConfiguration;
import org.apache.synapse.config.xml.MessageStoreSerializer;
import org.apache.synapse.config.xml.MultiXMLConfigurationBuilder;
import org.apache.synapse.message.store.MessageStore;

import java.io.File;

public class MessageStoreStore extends AbstractStore<MessageStore> {

    public MessageStoreStore(String configPath, String configName) {
        super(configPath);
    }

    @Override
    protected OMElement saveToFile(MessageStore store, SynapseConfiguration synapseConfig) {
        try {
            return serializer.serializeMessageStore(store, synapseConfig, null);
        } catch (Exception e) {
            handleException("Error while saving the Message Store: " + store.getName() + " to " +
                    "the file system", e);
        }
        return null;
    }

    @Override
    protected void deleteFile(String fileName, SynapseConfiguration config) {

        File msDir = new File(configPath, MultiXMLConfigurationBuilder.MESSAGE_STORE_DIR);

        if (!msDir.exists()) {
            return;
        }

        File msFile = new File(msDir, fileName);

        config.getArtifactDeploymentStore().addBackedUpArtifact(
                msFile.getAbsolutePath());
        msFile.delete();
    }

    @Override
    protected MessageStore getObjectToPersist(String name, SynapseConfiguration config) {
        return config.getMessageStore(name);
    }

    @Override
    protected String getFileName(MessageStore messageStore) {
        return messageStore.getFileName();
    }

    @Override
    protected OMElement serialize(MessageStore obj) {
        return MessageStoreSerializer.serializeMessageStore(null, obj);
    }
}
